@@ -1,7 +1,7 @@
 /*
  balloon.js -- a DHTML library for balloon tooltips
 
- $Id: balloon.js 24862 2011-04-28 17:50:16Z lstein $
+ $Id: balloon.js 24888 2011-05-04 14:59:48Z lstein $
 
  See http://www.gmod.org/wiki/index.php/Popup_Balloons
  for documentation.
@@ -43,7 +43,6 @@ var balloonIsSuppressed;
 var tooltipIsSuppressed;
 var supportsTouch = ('createTouch' in document);
 
-
 //////////////////////////////////////////////////////////////////////////
 // This is constructor that is called to initialize the Balloon object  //
 //////////////////////////////////////////////////////////////////////////
@@ -62,17 +61,20 @@ var Balloon = function () {
   // scrolling aborts unsticky balloons
   document.onscroll    = Balloon.prototype.hideTooltip;
 
-  // make balloons go away if the page is unloading or waiting
-  // to unload.
-  window.onbeforeunload = function(){
-    Balloon.prototype.hideTooltip(1);
-    balloonIsSuppressed = true;
-  };
-
   // for IE, the balloons can;t start until the page is finished loading
   // set a flag that will get toggled when loading is finished
   if (this.isIE()) {
-    this.suppress = true;
+      this.suppress = true;
+  } else {
+      // make balloons go away if the page is unloading or waiting
+      // to unload. Note that we do not call this for IE because
+      // IE8 has a bug which triggers beforeunload event every time
+      // an anchor is clicked, and stopping event propagation doesn't
+      // seem to fix it.
+      window.onbeforeunload = function(){
+            Balloon.prototype.hideTooltip(1);
+            balloonIsSuppressed = true;
+      };
   }
 
   return this;
@@ -83,8 +85,7 @@ var Balloon = function () {
 // delay time to avoid balloons popping up on rapid mouseover events    //
 //////////////////////////////////////////////////////////////////////////
 Balloon.prototype.showTooltip = function(evt,caption,sticky,width,height) {
-			      
-	
+
   // If the object is not configured by now, fall back to default
   if (!this.configured) {
     BalloonConfig(this,'GBubble');
@@ -268,6 +269,8 @@ Balloon.prototype.showTooltip = function(evt,caption,sticky,width,height) {
   var delay = mouseOver ? this.delayTime : 1;
   this.timeoutTooltip = window.setTimeout(this.doShowTooltip,delay);
   this.pending = true;
+
+  return false;
 }
 
 
@@ -329,10 +332,9 @@ Balloon.prototype.doShowTooltip = function() {
   self.pageRight  = pageLeft + pageWidth;
 
   // do we have a cursor position?
-  if (!(self.activeTop && self.activeRight)) {
-//     self.setActiveCoordinates();
-  }
-
+  //  if (!(self.activeTop && self.activeRight)) {
+  // self.setActiveCoordinates();
+  // }
 
   // balloon orientation
   var vOrient = self.activeTop > pageMid ? 'up' : 'down';
@@ -374,6 +376,8 @@ Balloon.prototype.doShowTooltip = function() {
   self.startY = self.activeTop;
 
   self.fade(0,self.opacity,self.fadeIn);
+
+  return false;
 }
 
 Balloon.prototype.addCloseButton = function () {
@@ -434,7 +438,7 @@ Balloon.prototype.makeBalloon = function() {
   //self.parts.push(balloon);
 
   if (self.displayTime)  {
-    self.timeoutAutoClose = window.setTimeout(this.hideTooltip,self.displayTime);
+      self.timeoutAutoClose = window.setTimeout(this.hideTooltip,self.displayTime);
   }
   return balloon;
 }
@@ -652,11 +656,20 @@ Balloon.prototype.setBalloonStyle = function(vOrient,hOrient,pageWidth,pageLeft)
   }
 
   // Make edges match the main balloon body
-  self.setStyle('topRight','height', self.getLoc(balloon,'height'));
+  self.setStyle('topRight', 'height', self.getLoc(balloon,'height'));
   self.setStyle('bottomLeft','width', self.getLoc(balloon,'width'));
 
+  // next section is some debugging for IE8 problem
+  //  var b = self.activeBalloon;
+  //  var bwidth  = self.getLoc(b,'width');
+  //  self.setStyle(b,'right',null);
+  //  var newLeft = self.activeLeft - bwidth;
+  //  self.setStyle(b,'left',newLeft);
+  
   self.hOrient = hOrient;
   self.vOrient = vOrient;
+
+  self.adjustBalloonPosition();  // for IE8
 }
 
 
@@ -711,9 +724,12 @@ Balloon.prototype.doOpacity = function(op,opc,el) {
   self.setStyle(el,'KhtmlOpacity',op);
 }
 
-Balloon.prototype.hideTooltip = function(override) { 
+Balloon.prototype.hideTooltip = function(override) {
+
   // some browsers pass the event object == we don't want it
+  if (override == null)  override = false;
   if (override && typeof override == 'object') override = false;
+
   if (balloonIsSticky && !override) return false;
 
   var self = currentBalloonClass;
@@ -747,7 +763,7 @@ Balloon.prototype.cleanup = function() {
   else {
     body = document.body;
   }
-
+  
   var bubble = $('balloon');
   var close  = $('closeButton');
   var cont   = $('container');
@@ -788,11 +804,6 @@ Balloon.prototype.setActiveCoordinates = function(evt) {
 
   var scrollTop  = 0;
   var scrollLeft = 0;
-//  Why?  I do not know. perhaps a vestigial patch?
-//  if (self.isIE()) {
-//    var scrollTop  = window.pageYOffset || document.documentElement.scrollTop  || 0; 
-//    var scrollLeft = window.pageXOffset || document.documentElement.scrollLeft || 0;
-//  }
 
   var XY = self.eventXY(evt);
   adjustment   = self.hOffset < 20 ? 10 : 0;
@@ -808,9 +819,18 @@ Balloon.prototype.setActiveCoordinates = function(evt) {
     var deltaY = Math.abs(self.activeTop - self.startY);
 
     if (deltaX > self.stopTrackingX || deltaY > self.stopTrackingY) {
-      self.hideTooltip();
+	self.hideTooltip();
     }
     else {
+	self.adjustBalloonPosition();
+    }
+  }
+
+  return true;
+}
+
+Balloon.prototype.adjustBalloonPosition = function() {
+      var self = currentBalloonClass;
       var b = self.activeBalloon;
       var bwidth  = self.getLoc(b,'width');
       var bheight = self.getLoc(b,'height');
@@ -832,10 +852,6 @@ Balloon.prototype.setActiveCoordinates = function(evt) {
       else if (self.vOrient == 'down') {
         self.setStyle(b,'top',self.activeBottom);
       }
-    }
-  }
-
-  return true;
 }
 
 ////
