@@ -1199,7 +1199,7 @@ sub make_map {
 	$mousedown = $balloonclick =~ /^(http|ftp):/
 	    ? "$balloon_ct.showTooltip(event,'<iframe width='+$balloon_ct.maxWidth+' height=$height " .
 	      "frameborder=0 src=$balloonclick></iframe>',$stick,$balloon_ct.maxWidth)"
-	      : "$balloon_ct.showTooltip(event,'$balloonclick',$stick)";
+	    : "$balloon_ct.showTooltip(event,'$balloonclick',$stick)";
 	undef $href;
 	undef $target;
       }
@@ -1207,10 +1207,7 @@ sub make_map {
 
     # workarounds to accomodate observation that some browsers don't respect cursor:pointer styles in
     # <area> tags unless there is an href defined
-    my $agent =  CGI->user_agent || '';
-    $href    ||=     $agent =~ /msie/i    ? 'javascript:void(0)'
-                   : $agent =~ /firefox/i ? undef
-                   : 'javascript:void(0)';
+    $href    ||=     'javascript:void(0)';
 
     my %attributes = (
 		      title       => $title,
